Index: res/res_srtp.c
===================================================================
--- res/res_srtp.c	(revision 376049)
+++ res/res_srtp.c	(working copy)
@@ -355,7 +355,9 @@
 
 			/* dealloc first */
 			ast_debug(5, "SRTP destroy before re-create\n");
+			ast_log(LOG_NOTICE, "srtp_diagnostic_patch: attempting srtp_dealloc at %p\n", &srtp->session);
 			srtp_dealloc(srtp->session);
+			ast_log(LOG_NOTICE, "srtp_diagnostic_patch: made it through srtp_dealloc at %p\n", &srtp->session);
 
 			/* get the count */
 			policies_count = ao2_container_count(srtp->policies);
@@ -366,7 +368,9 @@
 
 			ast_debug(5, "SRTP try to re-create\n");
 			if (policy) {
+				ast_log(LOG_NOTICE, "srtp_diagnostic_patch: calling srtp_create at %p\n", &srtp->session);
 				if (srtp_create(&srtp->session, &policy->sp) == err_status_ok) {
+					ast_log(LOG_NOTICE, "srtp_diagnostic_patch: result of srtp_create at %p was success\n", &srtp->session);
 					ast_debug(5, "SRTP re-created with first policy\n");
 					ao2_t_ref(policy, -1, "Unreffing first policy for re-creating srtp session");
 
@@ -383,6 +387,8 @@
 					retry++;
 					ao2_iterator_destroy(&it);
 					goto tryagain;
+				} else {
+					ast_log(LOG_NOTICE, "srtp_diagnostic_patch: rsult of srtp_create at %p was failure\n", &srtp->session);
 				}
 				ao2_t_ref(policy, -1, "Unreffing first policy after srtp_create failed");
 			}
@@ -429,6 +435,7 @@
 static int ast_srtp_create(struct ast_srtp **srtp, struct ast_rtp_instance *rtp, struct ast_srtp_policy *policy)
 {
 	struct ast_srtp *temp;
+	err_status_t res;
 
 	if (!(temp = res_srtp_new())) {
 		return -1;
@@ -436,10 +443,15 @@
 	ast_module_ref(ast_module_info->self);
 
 	/* Any failures after this point can use ast_srtp_destroy to destroy the instance */
-	if (srtp_create(&temp->session, &policy->sp) != err_status_ok) {
+	ast_log(LOG_NOTICE, "srtp_diagnostic_patch: attempting srtp_create at %p\n", &temp->session);
+	res = srtp_create(&temp->session, &policy->sp);
+	ast_log(LOG_NOTICE, "srtp_diagnostic_patch: srtp_errstr = %s\n", srtp_errstr(res));
+	if (res != err_status_ok) {
+		ast_log(LOG_NOTICE, "srtp_diagnosic_patch: result of srtp_create at %p was failure\n", &temp->session);
 		ast_srtp_destroy(temp);
 		return -1;
 	}
+	ast_log(LOG_NOTICE, "srtp_diagnostic_patch: result of srtp_create at %p was success\n", &temp->session);
 
 	temp->rtp = rtp;
 	*srtp = temp;
@@ -460,7 +472,10 @@
 static void ast_srtp_destroy(struct ast_srtp *srtp)
 {
 	if (srtp->session) {
+		ast_log(LOG_NOTICE, "srtp_diagnostic_patch: attempting srtp_destroy at %p\n", &srtp->session);
+		usleep(75000);
 		srtp_dealloc(srtp->session);
+		ast_log(LOG_NOTICE, "srtp_diagnostic_patch: Made it through srtp_destroy at %p\n", &srtp->session);
 	}
 
 	ao2_t_callback(srtp->policies, OBJ_UNLINK | OBJ_NODATA | OBJ_MULTIPLE, NULL, NULL, "Unallocate policy");

